@@ -21,6 +21,7 @@ TIMEOUT=86400
 
 def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None, nodes=None,
            force=False, auto_release=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
+           log_mapping=None,
            file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None,
            reserve_on_fail=False,
            no_cache_support=False,
@@ -76,6 +77,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'read_mount': read_mount,
         'write_mount': write_mount,
         'mount': mount,
+        'log_mapping': log_mapping,
 
         'notification_endpoint': notification_endpoint,
         'notification_topic': notification_topic,
@@ -337,6 +339,9 @@ def fix_by_opt(desc, opt, check_cluster):
         if opt.get('write_mount'):
             extend(task_desc['OutputMapping'], reverse_kv(trans_mount(opt['write_mount'])))
 
+        if opt.get('log_mapping'):
+            extend(task_desc['LogMapping'], reverse_kv(trans_mount(opt['log_mapping'])))
+
         if opt.get('lock'):
             task_desc['Parameters']['InputMappingConfig']['Lock'] = opt['lock']
         if opt.get('locale'):
@@ -478,6 +483,11 @@ def trans_file_to_job_desc(file, check_cluster):
                 w_mount_m = trans_mount(cf.get(DEFAULT,'write_mount'))
                 extend(task_desc['OutputMapping'], reverse_kv(w_mount_m))
 
+            if cf.has_option(DEFAULT,'log_mapping'):
+                log_m = trans_mount(cf.get(DEFAULT,'log_mapping'))
+                extend(task_desc['LogMapping'], reverse_kv(log_m))
+
+
             if cf.has_option(DEFAULT, 'user_data'):
                 user_data_m = trans_user_data(cf.get(DEFAULT, 'user_data'))
                 if not task_desc['AutoCluster'].get('UserData'):
@@ -625,6 +635,10 @@ def trans_file_to_job_desc(file, check_cluster):
             w_mount_m = trans_mount(cf.get(sec,'write_mount'))
             extend(task_desc['OutputMapping'], reverse_kv(w_mount_m))
 
+        if cf.has_option(sec,'log_mapping'):
+            log_m = trans_mount(cf.get(sec,'log_mapping'))
+            extend(task_desc['LogMapping'], reverse_kv(log_m))
+
         if cf.has_option(sec,'lock'):
             task_desc['Parameters']['InputMappingConfig']['Lock'] = cf.get('lock')
         if cf.has_option(sec,'locale'):
