@@ -128,43 +128,66 @@ def get_instance_type(arr, cpu,mem):
            return n.get('name')
     return arr[-1].get('name')
 
+def _ins_types_cmp(a,b):
+    if 'bcs.' in a.get('name'):
+        return 1
+    if 'sn1.' in b.get('name') or 'sn2.' in b.get('name'):
+        return 1
+    return -1
+
 
 def replaceTemplate4GATK(dist):
 
-    ins_types = (client.list_instance_types() or [])
-
-
     # main.sh
-    with open(os.path.join(dist, 'main.sh')) as f:
-        str = f.read()
-        str = str.replace('#{{INSTANCE_TYPE:4:8}}', get_instance_type(ins_types, 4,8))
-    with open(os.path.join(dist, 'main.sh'), 'w') as f:
-        f.write(str)
-
-    # wdl
-    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.wdl')) as f:
-        str = f.read()
-        str = str.replace('#{{INSTANCE_TYPE:4:8}}', get_instance_type(ins_types, 4, 8))
-        str = str.replace('#{{INSTANCE_TYPE:8:16}}', get_instance_type(ins_types, 8, 16))
-        str = str.replace('#{{INSTANCE_TYPE:16:32}}', get_instance_type(ins_types, 16, 32))
-    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.wdl'), 'w') as f:
-        f.write(str)
-
+    _replace_template(os.path.join(dist, 'gatk4-data-processing', 'main.sh'))
     # inputs
-    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.inputs.json')) as f:
-        str = f.read()
-        str = str.replace('#{{GENOMICS_PUBLIC_BUCKET}}', TEMPLATE_GATK_BUCKETS.get(config.getRegion()) or 'cn-beijing')
-    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.inputs.json'), 'w') as f:
-        f.write(str)
+    _replace_template(os.path.join(dist, 'gatk4-data-processing','src',
+                                   'processing-for-variant-discovery-gatk4.hg38.wgs.inputs.json'))
+
+    # main.sh2
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'haplotypecaller-gvcf-gatk4-main.sh'))
+    # inputs2
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels','src',
+                           'haplotypecaller-gvcf-gatk4.hg38.wgs.inputs.json'))
+
+    # main.sh3
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'joint-discovery-gatk4-main.sh'))
+    # inputs3
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'src',
+                                   'joint-discovery-gatk4.hg38.wgs.inputs.json'))
 
 
 def replaceTemplate4WDL(dist):
-    ins_types = (client.list_instance_types() or [])
+
 
     # main.sh
-    with open(os.path.join(dist, 'main.sh')) as f:
-        str = f.read()
-        str = str.replace('#{{INSTANCE_TYPE:4:8}}', get_instance_type(ins_types, 4, 8))
-    with open(os.path.join(dist, 'main.sh'), 'w') as f:
-        f.write(str)
+    _replace_template(os.path.join(dist, 'main.sh'))
 
+
+def _replace_template(p):
+    ins_types = (client.list_instance_types() or [])
+
+    # sort
+    ins_types.sort(cmp=_ins_types_cmp)
+
+    bucket = TEMPLATE_GATK_BUCKETS.get(config.getRegion())
+
+    if not bucket:
+        raise Exception("This region do not support WDL")
+
+
+
+    with open(p) as f:
+        str = f.read()
+
+        str = str.replace('#{{INSTANCE_TYPE:4:8}}', get_instance_type(ins_types, 4, 8))
+        str = str.replace('#{{INSTANCE_TYPE:4:16}}', get_instance_type(ins_types, 4, 16))
+        str = str.replace('#{{INSTANCE_TYPE:8:16}}', get_instance_type(ins_types, 8, 16))
+        str = str.replace('#{{INSTANCE_TYPE:16:32}}', get_instance_type(ins_types, 16, 32))
+        str = str.replace('#{{INSTANCE_TYPE:8:32}}', get_instance_type(ins_types, 8, 32))
+        str = str.replace('#{{INSTANCE_TYPE:32:128}}', get_instance_type(ins_types, 32, 128))
+
+        str = str.replace('#{{GENOMICS_PUBLIC_BUCKET}}', bucket)
+
+    with open(p, 'w') as f:
+        f.write(str)
