@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 import json
 import os
-from ..util import client,result_cache, config
+from ..util import client,result_cache, config,oss_client
 from terminal import yellow,blue
 from ..const import CMD
 import re
@@ -216,28 +216,51 @@ def trans_disk(disk):
         raise Exception(
             'Invalid disk format, it should like this: --disk system:ephemeral:40,data:cloud:500:/home/disk, append -h for more')
 
+def check_default_osspath(m):
+    if not m.get('osspath'):
+        print(yellow('\n  [WARN]: %s\n' % 'default osspath is recommended to set, use: "bcs set -o <osspath>'))
+        return
 
+    try:
+        oss_client.list(m.get('osspath'))
+
+    except Exception as e:
+        print(yellow('\n  [WARN]: %s\n' % 'You need to change osspath too: bcs set -o <osspath>'))
 
 def set_default_type_n_image():
-    # if not found default type
-    # or not a available type
-    m = config.getConfigs(config.COMMON)
-    default_type = m.get('defaulttype')
 
-    arr = client.list_instance_types()
-    
-    if default_type:
-      for n in arr:
-        if default_type == n['name']:
-          return
-          
-    if len(arr)>0:
-       m['defaulttype'] = arr[0]['name']
+    m = config.getConfigs(config.COMMON)
 
     # if not found default image
     default_image = m.get('defaultimage')
     if not default_image:
         m['defaultimage']='img-ubuntu'
+        print(yellow('\n  [WARN]: defaultimage: %s' % m['defaultimage']))
 
     config.setConfigs(config.COMMON, m)
 
+
+
+    # if not found default type
+    # or not a available type
+    default_type = m.get('defaulttype')
+    if not default_type:
+        print(yellow('\n  [WARN]: %s\n' % 'defaulttype is recommended to set, use: "bcs set -t <instance_type>", and type "bcs t" to see more'))
+
+    # arr = client.list_instance_types()
+    #
+    # if default_type:
+    #   for n in arr:
+    #     if default_type == n['name']:
+    #       return
+    #
+    # if len(arr)>0:
+    #    m['defaulttype'] = arr[0]['name']
+
+def check_default_vpc_cidr_block():
+
+    m = config.getConfigs(config.COMMON)
+
+    vpc_cidr_block = m.get('vpc_cidr_block')
+    if not vpc_cidr_block:
+        print(yellow('\n  [WARN]: %s\n' % 'vpc_cidr_block is recommended to set, use "bcs set --vpc_cidr_block [vpc_cidr_block]"'))
